'use strict';

var _reactDocgen = require('react-docgen');

var _componentNameHandler = require('./handlers/componentNameHandler');

var _componentNameHandler2 = _interopRequireDefault(_componentNameHandler);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Merge custom handlers with reactDoc defaultHandlers
_reactDocgen.defaultHandlers.unshift(_componentNameHandler2.default);

var json = {};

function ReactExtractComponentMeta() {
  var config = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};

  this.config = {};
  var configDefaults = {
    'filter': /component/gi,
    'output': {
      'filename': 'components-meta.json'
    }
  };

  Object.assign(this.config, configDefaults, config);
}

ReactExtractComponentMeta.prototype.apply = function (compiler) {

  // Get compilation instance
  compiler.plugin('emit', function (compilation, callback) {

    // Explore each chunk in the compilation
    compilation.chunks.forEach(function (chunk) {

      // Explore each module within the chunk
      chunk.modules.forEach(function (module) {

        var resourcePath = module.rawRequest;

        // Filter through the valid files as specified in config
        if (Array.isArray(resourcePath.match(this.config.filter))) {
          var source = module._source._value;
          var componentInfo = {};

          // Parse the source with reactDoc.parse
          try {
            componentInfo = (0, _reactDocgen.parse)(source, null, _reactDocgen.defaultHandlers);
          } catch (e) {
            console.log(resourcePath + " is not a React Component" + "\n");
          }

          if (componentInfo.name) {
            var getComponentName = componentInfo.name;
            json[getComponentName] = componentInfo;
          }
        }
      }, this);
    }, this);

    // Add the JSON file in assets
    json = JSON.stringify(json);
    compilation.assets[this.config.output.filename] = {
      source: function source() {
        return json;
      },
      size: function size() {
        return json.length;
      }
    };

    callback();
  }.bind(this));
};

module.exports = ReactExtractComponentMeta;